==> process-infinispan-persistence-springboot-0.13.1-sources.jar: org/acme/deals/DealreviewsModel.java <==
package org.acme.deals;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "dealreviews", name = "Dealreviews", hidden = false)
public class DealreviewsModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("deal", this.deal);
        params.put("review", this.review);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.deal = (java.lang.String) params.get("deal");
        this.review = (java.lang.String) params.get("review");
        this.traveller = (org.acme.deals.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "deal")
    @javax.validation.Valid()
    private java.lang.String deal;

    public java.lang.String getDeal() {
        return deal;
    }

    public void setDeal(java.lang.String deal) {
        this.deal = deal;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "review")
    @javax.validation.Valid()
    private java.lang.String review;

    public java.lang.String getReview() {
        return review;
    }

    public void setReview(java.lang.String review) {
        this.review = review;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.deals.Traveller traveller;

    public org.acme.deals.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.deals.Traveller traveller) {
        this.traveller = traveller;
    }
}

==> process-infinispan-persistence-springboot-0.17.0-sources.jar: org/acme/deals/DealreviewsModel.java <==
package org.acme.deals;

import java.util.Map;
import java.util.HashMap;

@org.kie.internal.kogito.codegen.Generated(value = "kogito-codegen", reference = "dealreviews", name = "Dealreviews", hidden = false)
public class DealreviewsModel implements org.kie.kogito.Model {

    private String id;

    public void setId(String id) {
        this.id = id;
    }

    public String getId() {
        return this.id;
    }

    @Override
    public Map<String, Object> toMap() {
        Map<String, Object> params = new HashMap();
        params.put("deal", this.deal);
        params.put("review", this.review);
        params.put("traveller", this.traveller);
        return params;
    }

    @Override
    public void fromMap(Map<String, Object> params) {
        fromMap(null, params);
    }

    @Override
    public void update(Map<String, Object> params) {
        fromMap(getId(), params);
    }

    public void fromMap(String id, Map<String, Object> params) {
        this.id = id;
        this.deal = (java.lang.String) params.get("deal");
        this.review = (java.lang.String) params.get("review");
        this.traveller = (org.acme.deals.Traveller) params.get("traveller");
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "deal")
    @javax.validation.Valid()
    private java.lang.String deal;

    public java.lang.String getDeal() {
        return deal;
    }

    public void setDeal(java.lang.String deal) {
        this.deal = deal;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "review")
    @javax.validation.Valid()
    private java.lang.String review;

    public java.lang.String getReview() {
        return review;
    }

    public void setReview(java.lang.String review) {
        this.review = review;
    }

    @org.kie.internal.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.deals.Traveller traveller;

    public org.acme.deals.Traveller getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.deals.Traveller traveller) {
        this.traveller = traveller;
    }

    public DealreviewsModelOutput toOutput() {
        DealreviewsModelOutput result = new DealreviewsModelOutput();
        result.setId(getId());
        result.setDeal(getDeal());
        result.setReview(getReview());
        result.setTraveller(getTraveller());
        return result;
    }
}
